ad_page_contract {

    Simple add/edit form for resources

    @author jade@safe4all.org
    @creation-date 2003-08-27
    @cvs-id $Id: add-edit.tcl,v 1.6 2005/03/01 00:01:20 jeffd Exp $

    @return context_bar Context bar.
    @return title Page title.

} {

    resource_revision_id:integer,optional
    {resource_name ""}
    {description ""}
    {categories:array,multiple ""}

} -properties {

    context_bar:onevalue
    title:onevalue

}

# --------------------------------------------------------------- #
# the unique identifier for this package
set package_id [ad_conn package_id]
set user_id    [auth::require_login]
set url        [ad_conn package_url]

if {[exists_and_not_null resource_id]} {
    set title "Edit a $resource_term_lower"
    set context_bar [ad_context_bar "Edit $resource_term"]

    # permissions
    permission::require_permission -party_id $user_id -object_id $package_id -privilege write
} else {
    set title "Add a resource"
    set context_bar [ad_context_bar "New resource"]

    # permissions
    permission::require_permission -party_id $user_id -object_id $package_id -privilege create
}


ad_form -name add_edit -form {
    resource_revision_id:key

    {resource_name:text
        {label "Resource name"}
        {value $resource_name}
        {html {size 39}}
    }

    {description:text(textarea)
        {label "Description"}
        {optional}
        {value $description}
        {html { rows 5 cols 40 wrap soft}}}

}


if {[exists_and_not_null resource_revision_id]} {
    set values [db_list get_categories { }]
} else {
    set values ""
}


foreach type [db_list_of_lists get_resource_types { }] {

    set category_type_id [lindex $type 0]
    set type_short_name  [lindex $type 1]
    
    ns_log Notice "category_type_id $category_type_id"
    
    set ae_def "
        {categories.$category_type_id:text(checkbox),multiple 
             {label \"Select: [set type_short_name]\"} 
             {options {[db_list_of_lists get_category_items { }]} } 
             {values [list [set values]]}
         } " 

    ns_log Notice "ae_def: $ae_def"

    ad_form -extend -name add_edit -form $ae_def 

}


ad_form -extend -name add_edit \
    -select_query_name resource_query \
    -on_submit {

	set user_id [ad_conn user_id]
	set peeraddr [ad_conn peeraddr]
	
    } -new_data {
	
	set resource_revision_id [db_exec_plsql new_resource_item { *SQL* }]
	set resource_item_id     [db_string get_item_id { }]
	
	if {[info exists categories]} {
	    set searchToken [array startsearch categories]
	    
	    while {[array anymore categories $searchToken]} {
		
		set keyname [array nextelement categories $searchToken]
		
		set categories_to_insert $categories($keyname)
		
		foreach category_to_insert $categories_to_insert {
		    db_dml insert_category { }
		}
	    }
	}
	
	permission::grant -party_id $user_id -object_id $resource_item_id -privilege write
	
	util_memoize_flush "resource_list_pending_get_count_cached"
	util_memoize_flush "resource_list_get_count_cached"
	
	ad_returnredirect "[set url]view/$resource_item_id"
	ad_script_abort
	
    } -edit_data {
	set resource_item_id [db_string get_item_id { }]
	
	set resource_revision_id [db_exec_plsql new_resource_revision { *SQL* }]
	
	db_dml delete_categories { }
	
	if {[info exists categories]} {
	    set searchToken [array startsearch categories]
	    
	    while {[array anymore categories $searchToken]} {
		
		set keyname [array nextelement categories $searchToken]
		
		set categories_to_insert $categories($keyname)
		
		foreach category_to_insert $categories_to_insert {
		    db_dml insert_category { }
		}
	    }
	}
	permission::grant -party_id $user_id -object_id $resource_item_id -privilege write
	
    } -after_submit {
	
	ad_returnredirect "[set url]view/$resource_item_id"
	ad_script_abort
    }
